==> haskell-tasty-hunit-0.10.0.1-22-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-hunit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-hunit
version: 0.10.0.1
id: tasty-hunit-0.10.0.1-HrI9K4dLTmTLS8EBoi5oY
key: tasty-hunit-0.10.0.1-HrI9K4dLTmTLS8EBoi5oY
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/tasty
synopsis: HUnit support for the Tasty test framework.
description:
    HUnit support for the Tasty test framework.
category: Testing
abi: 884158b23ae21a084b1944e6ad796940
exposed: True
exposed-modules:
    Test.Tasty.HUnit
hidden-modules: Test.Tasty.HUnit.Orig Test.Tasty.HUnit.Steps
import-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-hunit-0.10.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-hunit-0.10.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/tasty-hunit-0.10.0.1
hs-libraries: HStasty-hunit-0.10.0.1-HrI9K4dLTmTLS8EBoi5oY
depends:
    base-4.11.1.0 tasty-1.1.0.2-J1Ykr4HrPV5zER5XhOF7G
    call-stack-0.1.0-Eiz5FM8yQXpI3vyQ1Rt4Jq
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             tasty-1.1.0.2-J1Ykr4HrPV5zER5XhOF7G=a8d4ce527162fa4472ebda77d927e1ce
             call-stack-0.1.0-Eiz5FM8yQXpI3vyQ1Rt4Jq=842aa1f6a3dc6ac6e201dfeb465a9bd8
haddock-interfaces: /usr/share/doc/haskell-tasty-hunit/html/tasty-hunit.haddock
haddock-html: /usr/share/doc/haskell-tasty-hunit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-hunit-0.10.0.1-23-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-hunit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-hunit
version: 0.10.0.1
id: tasty-hunit-0.10.0.1-K46HX1oXc1rHEdA71l39bp
key: tasty-hunit-0.10.0.1-K46HX1oXc1rHEdA71l39bp
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/tasty
synopsis: HUnit support for the Tasty test framework.
description:
    HUnit support for the Tasty test framework.
category: Testing
abi: 4cb05eb7dca5a4fb31c6e05fc6d279ed
exposed: True
exposed-modules:
    Test.Tasty.HUnit
hidden-modules: Test.Tasty.HUnit.Orig Test.Tasty.HUnit.Steps
import-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-hunit-0.10.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-hunit-0.10.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/tasty-hunit-0.10.0.1
hs-libraries: HStasty-hunit-0.10.0.1-K46HX1oXc1rHEdA71l39bp
depends:
    base-4.11.1.0 tasty-1.1.0.3-FF9Bf2Xp2BG6DZ1uQXD9sH
    call-stack-0.1.0-Eiz5FM8yQXpI3vyQ1Rt4Jq
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             tasty-1.1.0.3-FF9Bf2Xp2BG6DZ1uQXD9sH=82080caf5dc3107fc22e84ac0a1da579
             call-stack-0.1.0-Eiz5FM8yQXpI3vyQ1Rt4Jq=842aa1f6a3dc6ac6e201dfeb465a9bd8
haddock-interfaces: /usr/share/doc/haskell-tasty-hunit/html/tasty-hunit.haddock
haddock-html: /usr/share/doc/haskell-tasty-hunit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
